App class

An individual AWS Firewall Manager application.

Constructors

App({required String appName, required int port, required String protocol})
App.fromJson(Map<String, dynamic> json)
factory

Properties

appName → String
The application's name.
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
The application's port number, for example 80.
final
protocol → String
The IP protocol name or number. The name can be one of tcp, udp, or icmp. For information on possible numbers, see Protocol Numbers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited