AppsListDataSummary class

Details of the AWS Firewall Manager applications list.

Constructors

AppsListDataSummary({List<App>? appsList, String? listArn, String? listId, String? listName})
AppsListDataSummary.fromJson(Map<String, dynamic> json)
factory

Properties

appsList → List<App>?
An array of App objects in the AWS Firewall Manager applications list.
final
hashCode → int
The hash code for this object.
no setterinherited
listArn → String?
The Amazon Resource Name (ARN) of the applications list.
final
listId → String?
The ID of the applications list.
final
listName → String?
The name of the applications list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited