AwsEc2NetworkInterfaceViolation class

Violations for network interfaces associated with an EC2 instance.

Constructors

AwsEc2NetworkInterfaceViolation({List<String>? violatingSecurityGroups, String? violationTarget})
AwsEc2NetworkInterfaceViolation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
violatingSecurityGroups → List<String>?
List of security groups that violate the rules specified in the master security group of the AWS Firewall Manager policy.
final
violationTarget → String?
The resource ID of the network interface.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited