GetAdminAccountResponse class

Constructors

GetAdminAccountResponse({String? adminAccount, AccountRoleStatus? roleStatus})
GetAdminAccountResponse.fromJson(Map<String, dynamic> json)
factory

Properties

adminAccount → String?
The AWS account that is set as the AWS Firewall Manager administrator.
final
hashCode → int
The hash code for this object.
no setterinherited
roleStatus → AccountRoleStatus?
The status of the AWS account that you set as the AWS Firewall Manager administrator.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited