GetAppsListResponse class

Constructors

GetAppsListResponse({AppsListData? appsList, String? appsListArn})
GetAppsListResponse.fromJson(Map<String, dynamic> json)
factory

Properties

appsList → AppsListData?
Information about the specified AWS Firewall Manager applications list.
final
appsListArn → String?
The Amazon Resource Name (ARN) of the applications list.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited