GetNotificationChannelResponse class

Constructors

GetNotificationChannelResponse({String? snsRoleName, String? snsTopicArn})
GetNotificationChannelResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snsRoleName → String?
The IAM role that is used by AWS Firewall Manager to record activity to SNS.
final
snsTopicArn → String?
The SNS topic that records AWS Firewall Manager activity.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited