GetProtectionStatusResponse class

Constructors

GetProtectionStatusResponse({String? adminAccountId, String? data, String? nextToken, SecurityServiceType? serviceType})
GetProtectionStatusResponse.fromJson(Map<String, dynamic> json)
factory

Properties

adminAccountId → String?
The ID of the AWS Firewall administrator account for this policy.
final
data → String?
Details about the attack, including the following:
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If you have more objects than the number that you specified for MaxResults in the request, the response includes a NextToken value. To list more objects, submit another GetProtectionStatus request, and specify the NextToken value from the response in the NextToken value in the next request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceType → SecurityServiceType?
The service type that is protected by the policy. Currently, this is always SHIELD_ADVANCED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited