GetProtocolsListResponse class

Constructors

GetProtocolsListResponse({ProtocolsListData? protocolsList, String? protocolsListArn})
GetProtocolsListResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
protocolsList → ProtocolsListData?
Information about the specified AWS Firewall Manager protocols list.
final
protocolsListArn → String?
The Amazon Resource Name (ARN) of the specified protocols list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited