NetworkFirewallMissingSubnetViolation class

Violation details for AWS Network Firewall for an Availability Zone that's missing the expected Firewall Manager managed subnet.

Constructors

NetworkFirewallMissingSubnetViolation({String? availabilityZone, String? targetViolationReason, String? vpc, String? violationTarget})
NetworkFirewallMissingSubnetViolation.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZone → String?
The Availability Zone of a violating subnet.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetViolationReason → String?
The reason the resource has this violation, if one is available.
final
violationTarget → String?
The ID of the AWS Network Firewall or VPC resource that's in violation.
final
vpc → String?
The resource ID of the VPC associated with a violating subnet.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited