NetworkFirewallPolicyModifiedViolation class

Violation details for AWS Network Firewall for a firewall policy that has a different NetworkFirewallPolicyDescription than is required by the Firewall Manager policy.

Constructors

NetworkFirewallPolicyModifiedViolation({NetworkFirewallPolicyDescription? currentPolicyDescription, NetworkFirewallPolicyDescription? expectedPolicyDescription, String? violationTarget})
NetworkFirewallPolicyModifiedViolation.fromJson(Map<String, dynamic> json)
factory

Properties

currentPolicyDescription → NetworkFirewallPolicyDescription?
The policy that's currently in use in the individual account.
final
expectedPolicyDescription → NetworkFirewallPolicyDescription?
The policy that should be in use in the individual account in order to be compliant.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
violationTarget → String?
The ID of the AWS Network Firewall or VPC resource that's in violation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited