PartialMatch class

The reference rule that partially matches the ViolationTarget rule and violation reason.

Constructors

PartialMatch({String? reference, List<String>? targetViolationReasons})
PartialMatch.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reference → String?
The reference rule from the master security group of the AWS Firewall Manager policy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetViolationReasons → List<String>?
The violation reason.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited