ProtocolsListDataSummary class

Details of the AWS Firewall Manager protocols list.

Constructors

ProtocolsListDataSummary({String? listArn, String? listId, String? listName, List<String>? protocolsList})
ProtocolsListDataSummary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
listArn → String?
The Amazon Resource Name (ARN) of the specified protocols list.
final
listId → String?
The ID of the specified protocols list.
final
listName → String?
The name of the specified protocols list.
final
protocolsList → List<String>?
An array of protocols in the AWS Firewall Manager protocols list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited