PutProtocolsListResponse class

Constructors

PutProtocolsListResponse({ProtocolsListData? protocolsList, String? protocolsListArn})
PutProtocolsListResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
protocolsList → ProtocolsListData?
The details of the AWS Firewall Manager protocols list.
final
protocolsListArn → String?
The Amazon Resource Name (ARN) of the protocols list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited