ResourceViolation class

Violation detail based on resource type.

Constructors

ResourceViolation({AwsEc2InstanceViolation? awsEc2InstanceViolation, AwsEc2NetworkInterfaceViolation? awsEc2NetworkInterfaceViolation, AwsVPCSecurityGroupViolation? awsVPCSecurityGroupViolation, NetworkFirewallMissingExpectedRTViolation? networkFirewallMissingExpectedRTViolation, NetworkFirewallMissingFirewallViolation? networkFirewallMissingFirewallViolation, NetworkFirewallMissingSubnetViolation? networkFirewallMissingSubnetViolation, NetworkFirewallPolicyModifiedViolation? networkFirewallPolicyModifiedViolation})
ResourceViolation.fromJson(Map<String, dynamic> json)
factory

Properties

awsEc2InstanceViolation → AwsEc2InstanceViolation?
Violation details for an EC2 instance.
final
awsEc2NetworkInterfaceViolation → AwsEc2NetworkInterfaceViolation?
Violation details for network interface.
final
awsVPCSecurityGroupViolation → AwsVPCSecurityGroupViolation?
Violation details for security groups.
final
hashCode → int
The hash code for this object.
no setterinherited
networkFirewallMissingExpectedRTViolation → NetworkFirewallMissingExpectedRTViolation?
Violation detail for an Network Firewall policy that indicates that a subnet is not associated with the expected Firewall Manager managed route table.
final
networkFirewallMissingFirewallViolation → NetworkFirewallMissingFirewallViolation?
Violation detail for an Network Firewall policy that indicates that a subnet has no Firewall Manager managed firewall in its VPC.
final
networkFirewallMissingSubnetViolation → NetworkFirewallMissingSubnetViolation?
Violation detail for an Network Firewall policy that indicates that an Availability Zone is missing the expected Firewall Manager managed subnet.
final
networkFirewallPolicyModifiedViolation → NetworkFirewallPolicyModifiedViolation?
Violation detail for an Network Firewall policy that indicates that a firewall policy in an individual account has been modified in a way that makes it noncompliant. For example, the individual account owner might have deleted a rule group, changed the priority of a stateless rule group, or changed a policy default action.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited