SecurityGroupRuleDescription class

Describes a set of permissions for a security group rule.

Constructors

SecurityGroupRuleDescription({int? fromPort, String? iPV4Range, String? iPV6Range, String? prefixListId, String? protocol, int? toPort})
SecurityGroupRuleDescription.fromJson(Map<String, dynamic> json)
factory

Properties

fromPort → int?
The start of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 type number. A value of -1 indicates all ICMP/ICMPv6 types.
final
hashCode → int
The hash code for this object.
no setterinherited
iPV4Range → String?
The IPv4 ranges for the security group rule.
final
iPV6Range → String?
The IPv6 ranges for the security group rule.
final
prefixListId → String?
The ID of the prefix list for the security group rule.
final
protocol → String?
The IP protocol name (tcp, udp, icmp, icmpv6) or number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toPort → int?
The end of the port range for the TCP and UDP protocols, or an ICMP/ICMPv6 code. A value of -1 indicates all ICMP/ICMPv6 codes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited