StatelessRuleGroup class

AWS Network Firewall stateless rule group, used in a NetworkFirewallPolicyDescription.

Constructors

StatelessRuleGroup({int? priority, String? resourceId, String? ruleGroupName})
StatelessRuleGroup.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
priority → int?
The priority of the rule group. AWS Network Firewall evaluates the stateless rule groups in a firewall policy starting from the lowest priority setting.
final
resourceId → String?
The resource ID of the rule group.
final
ruleGroupName → String?
The name of the rule group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited